#!/usr/bin/python
# -*- coding: utf-8 -*-

import appier


class AdminController(appier.Controller):
    @appier.route("/admin/applier", "GET")
    @appier.ensure(token="admin", context="admin")
    def applier(self):
        mode = self.field("mode", "markdown")
        style = self.field("style", "base")
        attachments = self.field("attachments", [], cast=list)
        title = self.field("title")
        subtitle = self.field("subtitle")
        copyright = self.field("copyright")
        logo_url = self.field("logo_url")
        contents = self.field("contents")
        return self.template(
            "admin/applier.html.tpl",
            section="section:mailme:applier",
            mode=mode,
            style=style,
            attachments=attachments,
            title=title,
            subtitle=subtitle,
            copyright=copyright,
            logo_url=logo_url,
            contents=contents,
        )

    @appier.route("/admin/applier", "POST")
    @appier.ensure(token="admin", context="admin")
    def do_applier(self):
        mode = self.field("mode", "markdown")
        style = self.field("style", "base")
        attachments = self.field("attachments", [], cast=list)
        title = self.field("title")
        subtitle = self.field("subtitle")
        copyright = self.field("copyright")
        logo_url = self.field("logo_url")
        contents = self.field("contents", mandatory=True)
        return self.template(
            "admin/applier.html.tpl",
            section="section:mailme:applier",
            mode=mode,
            style=style,
            attachments=attachments,
            title=title,
            subtitle=subtitle,
            copyright=copyright,
            logo_url=logo_url,
            contents=contents,
        )



#!/usr/bin/python
# -*- coding: utf-8 -*-

import time

import appier

import mailme


class BaseAPIController(appier.Controller):
    @appier.route("/api/ping", "GET", json=True)
    def ping(self):
        return dict(time=time.time())

    @appier.route("/api/send", "POST", json=True)
    @appier.ensure(token="admin")
    def send(self):
        message = mailme.Message.new()
        message.approve()
        message.send()
        return message.map()

    @appier.route("/api/to_json", ("GET", "POST"), json=True)
    @appier.ensure(token="admin")
    def to_json(self):
        sender = self.field("sender")
        receivers = self.field("receivers", cast=list)
        mode = self.field("mode", "markdown")
        style = self.field("style", "base")
        attachments = self.field("attachments", [], cast=list)
        title = self.field("title")
        subtitle = self.field("subtitle")
        copyright = self.field("copyright")
        logo_url = self.field("logo_url")
        contents = self.field("contents", mandatory=True)
        data = dict(contents=contents)
        if sender:
            data["sender"] = sender
        if receivers:
            data["receivers"] = receivers
        if mode:
            data["mode"] = mode
        if style:
            data["style"] = style
        if attachments:
            data["attachments"] = attachments
        if title:
            data["title"] = title
        if subtitle:
            data["subtitle"] = subtitle
        if copyright:
            data["copyright"] = copyright
        if logo_url:
            data["logo_url"] = logo_url
        return data



#!/usr/bin/python
# -*- coding: utf-8 -*-

import appier
import appier_extras


class MailmeApp(appier.WebApp):
    def __init__(self, *args, **kwargs):
        appier.WebApp.__init__(
            self, name="mailme", parts=(appier_extras.AdminPart,), *args, **kwargs
        )

    def start(self, *args, **kwargs):
        appier.WebApp.start(self, *args, **kwargs)
        self.admin_part.add_section_item("Applier", "admin.applier", section="Mailme")

    def _version(self):
        return "0.1.3"

    def _description(self):
        return "Mailme"

    def _observations(self):
        return "Simple Email Sender API"


if __name__ == "__main__":
    app = MailmeApp()
    app.serve()
else:
    __path__ = []



#!/usr/bin/python
# -*- coding: utf-8 -*-

import appier
import appier_extras

from . import base


class Message(base.MailmeBase):
    sender = appier.field()

    receivers = appier.field(type=list)

    cc = appier.field(type=list, initial=[])

    bcc = appier.field(type=list, initial=[])

    reply_to = appier.field(type=list, initial=[])

    return_path = appier.field()

    priority = appier.field()

    inline = appier.field(type=bool, initial=True)

    style = appier.field(initial="base")

    mode = appier.field(initial="markdown")

    subject = appier.field(initial="Test email")

    attachments = appier.field(type=appier.Files)

    title = appier.field()

    subtitle = appier.field()

    contents = appier.field()

    copyright = appier.field()

    logo_url = appier.field(meta="url")

    @classmethod
    def validate(cls):
        return super(Message, cls).validate() + [
            appier.not_null("receivers"),
            appier.not_empty("receivers"),
        ]

    def send(self, owner=None):
        owner = owner or appier.get_app()

        # determines the right template so be used for the email
        # generation taking into account if this is just a test
        # email or a "real" one and if the inline engine is active
        if self.contents:
            file_name = "base.inline.html.tpl" if self.inline else "base.html.tpl"
        else:
            file_name = "test.html.tpl"

        kwargs = dict()
        if self.sender:
            kwargs["sender"] = self.sender

        appier_extras.admin.Base.send_email_g(
            owner,
            "email/%s" % file_name,
            receivers=self.receivers,
            cc=self.cc,
            bcc=self.bcc,
            reply_to=self.reply_to,
            return_path=self.return_path,
            priority=self.priority,
            inline=self.inline,
            style=self.style or "base",
            mode=self.mode or "markdown",
            subject=self.subject or "Test email",
            attachments=self.attachments if self.attachments else [],
            title=self.title or self.subject or "Test email",
            subtitle=self.subtitle,
            contents=self.contents,
            copyright=self.copyright,
            logo_url=self.logo_url or None,
            **kwargs
        )



#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import setuptools

setuptools.setup(
    name="mailme-py",
    version="0.1.3",
    author="Hive Solutions Lda.",
    author_email="development@hive.pt",
    description="Mailme",
    license="Apache License, Version 2.0",
    keywords="mailme smtp service",
    url="http://pushi.hive.pt",
    zip_safe=False,
    packages=[
        "mailme",
        "mailme.controllers",
        "mailme.controllers.api",
        "mailme.controllers.web",
        "mailme.models",
    ],
    test_suite="mailme.test",
    package_dir={"": os.path.normpath("src")},
    package_data={
        "mailme": [
            "templates/*.tpl",
            "templates/admin/*.tpl",
            "templates/email/*.tpl",
            "templates/styles/*.tpl",
        ]
    },
    install_requires=["netius", "appier", "appier-extras", "jinja2", "pymongo"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
)
